********************************
The sherpa.astro.io.types module
********************************

.. currentmodule:: sherpa.astro.io.types

.. automodule:: sherpa.astro.io.types

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      KeyType
      HeaderItem
      Header
      Column
      Block
      TableBlock
      SpectrumBlock
      SpecrespBlock
      MatrixBlock
      EboundsBlock
      ImageBlock
      BlockList
      BlockType

Class Inheritance Diagram
=========================

.. inheritance-diagram:: HeaderItem Header Column Block TableBlock SpectrumBlock SpecrespBlock MatrixBlock EboundsBlock ImageBlock BlockList
   :parts: 1
